@@ -13,6 +13,7 @@ from .async_tasks import AsyncTasks
 from .spa_events import GeckoSpaEvent
 
 from .const import GeckoConstants
+from .config import GeckoConfig, config_sleep
 from .driver import (
     GeckoAsyncUdpProtocol,
     GeckoPacketProtocolHandler,
@@ -192,6 +193,7 @@ class GeckoAsyncSpa(Observable):
 
         version_handler = await self._protocol.get(self._get_version_handler_func)
         if version_handler is None:
+            _LOGGER.error("Cannot get version, protocol retry count exceeded")
             await self._event_handler(
                 GeckoSpaEvent.CONNECTION_PROTOCOL_RETRY_COUNT_EXCEEDED
             )
@@ -217,6 +219,7 @@ class GeckoAsyncSpa(Observable):
 
         get_channel_handler = await self._protocol.get(self._get_channel_handler_func)
         if get_channel_handler is None:
+            _LOGGER.error("Cannot get channel, protocol retry count exceeded")
             await self._event_handler(
                 GeckoSpaEvent.CONNECTION_PROTOCOL_RETRY_COUNT_EXCEEDED
             )
@@ -236,6 +239,7 @@ class GeckoAsyncSpa(Observable):
             self._get_config_file_handler_func
         )
         if config_file_handler is None:
+            _LOGGER.error("Cannot get file, protocol retry count exceeded")
             await self._event_handler(
                 GeckoSpaEvent.CONNECTION_PROTOCOL_RETRY_COUNT_EXCEEDED
             )
@@ -333,6 +337,7 @@ class GeckoAsyncSpa(Observable):
                 parms=self.sendparms,
             ),
         ):
+            _LOGGER.error("Cannot get full struct, protocol retry count exceeded")
             await self._event_handler(
                 GeckoSpaEvent.CONNECTION_PROTOCOL_RETRY_COUNT_EXCEEDED
             )
@@ -373,6 +378,7 @@ class GeckoAsyncSpa(Observable):
             self._protocol.disconnect()
             self._protocol = None
         self._transport = None
+        self.unwatch_all()
 
     @property
     def isopen(self) -> bool:
@@ -389,7 +395,7 @@ class GeckoAsyncSpa(Observable):
         # are successful
         return (
             time.monotonic() - self._last_ping
-        ) < GeckoConstants.PING_FREQUENCY_IN_SECONDS * 2
+        ) < GeckoConfig.PING_FREQUENCY_IN_SECONDS * 2
 
     async def _async_on_packet(
         self, handler: GeckoPacketProtocolHandler, sender: tuple
@@ -419,10 +425,7 @@ class GeckoAsyncSpa(Observable):
 
                 assert self._protocol is not None
                 ping_handler = await self._protocol.get(
-                    lambda: GeckoPingProtocolHandler.request(
-                        parms=self.sendparms,
-                        timeout=GeckoConstants.PING_FREQUENCY_IN_SECONDS,
-                    ),
+                    lambda: GeckoPingProtocolHandler.request(parms=self.sendparms),
                     None,
                     1,
                 )
@@ -442,14 +445,19 @@ class GeckoAsyncSpa(Observable):
                     )
                     if (
                         time.monotonic() - self._last_ping
-                        > GeckoConstants.PING_DEVICE_NOT_RESPONDING_TIMEOUT
+                        > GeckoConfig.PING_DEVICE_NOT_RESPONDING_TIMEOUT_IN_SECONDS
                     ):
                         await self._event_handler(
                             GeckoSpaEvent.RUNNING_PING_NO_RESPONSE,
                             last_ping_at=self._last_ping_at,
                         )
 
-                await asyncio.sleep(GeckoConstants.PING_FREQUENCY_IN_SECONDS)
+                # Ping every couple of seconds until we have had a response
+                await config_sleep(
+                    2
+                    if self._last_ping_at is None
+                    else GeckoConfig.PING_FREQUENCY_IN_SECONDS
+                )
 
         except asyncio.CancelledError:
             _LOGGER.debug("Ping loop cancelled")
@@ -476,7 +484,7 @@ class GeckoAsyncSpa(Observable):
 
         _LOGGER.debug("Refresh loop started")
         while self.isopen:
-            await asyncio.sleep(GeckoConstants.SPA_PACK_REFRESH_FREQUENCY_IN_SECONDS)
+            await config_sleep(GeckoConfig.SPA_PACK_REFRESH_FREQUENCY_IN_SECONDS)
             if not self.is_connected:
                 continue
             if not self.is_responding_to_pings:
@@ -519,6 +527,7 @@ class GeckoAsyncSpa(Observable):
         )
 
         if pack_command_handler is None:
+            _LOGGER.error("Cannot set value, protocol retry count exceeded")
             await self._event_handler(GeckoSpaEvent.ERROR_PROTOCOL_RETRY_COUNT_EXCEEDED)
 
     def _on_set_value(self, pos, length, newvalue) -> None:
@@ -550,6 +559,7 @@ class GeckoAsyncSpa(Observable):
         )
 
         if pack_command_handler is None:
+            _LOGGER.error("Cannot press keypad, protocol retry count exceeded")
             await self._event_handler(GeckoSpaEvent.ERROR_PROTOCOL_RETRY_COUNT_EXCEEDED)
 
     def press(self, keypad) -> None:
@@ -582,6 +592,7 @@ class GeckoAsyncSpa(Observable):
         )
 
         if get_watercare_handler is None:
+            _LOGGER.error("Cannot get watercare, protocol retry count exceeded")
             await self._event_handler(GeckoSpaEvent.ERROR_PROTOCOL_RETRY_COUNT_EXCEEDED)
             return None
 
@@ -605,6 +616,7 @@ class GeckoAsyncSpa(Observable):
         )
 
         if set_watercare_handler is None:
+            _LOGGER.error("Cannot set version, protocol retry count exceeded")
             await self._event_handler(GeckoSpaEvent.ERROR_PROTOCOL_RETRY_COUNT_EXCEEDED)
 
     def _get_reminders_handler_func(self) -> GeckoRemindersProtocolHandler:
@@ -628,6 +640,7 @@ class GeckoAsyncSpa(Observable):
         )
 
         if get_reminders_handler is None:
+            _LOGGER.error("Cannot get reminders, protocol retry count exceeded")
             await self._event_handler(GeckoSpaEvent.ERROR_PROTOCOL_RETRY_COUNT_EXCEEDED)
             return []
 
